about summary refs log tree commit diff
path: root/pkgs/development/web
diff options
context:
space:
mode:
authorRok Garbas <rok@garbas.si>2013-07-03 04:26:27 +0200
committerRok Garbas <rok@garbas.si>2013-07-03 04:26:27 +0200
commit7816aa4ada8968a79ade52f1a8c689cf5fdeecb3 (patch)
treed999b70110ca02843047eae7c6aa0a9cbf4ebe76 /pkgs/development/web
parent0a527048eb9ccc230e76694f4ac1d33cebfd1627 (diff)
downloadnixlib-7816aa4ada8968a79ade52f1a8c689cf5fdeecb3.tar
nixlib-7816aa4ada8968a79ade52f1a8c689cf5fdeecb3.tar.gz
nixlib-7816aa4ada8968a79ade52f1a8c689cf5fdeecb3.tar.bz2
nixlib-7816aa4ada8968a79ade52f1a8c689cf5fdeecb3.tar.lz
nixlib-7816aa4ada8968a79ade52f1a8c689cf5fdeecb3.tar.xz
nixlib-7816aa4ada8968a79ade52f1a8c689cf5fdeecb3.tar.zst
nixlib-7816aa4ada8968a79ade52f1a8c689cf5fdeecb3.zip
plone: adding collective_recipe_template package
Diffstat (limited to 'pkgs/development/web')
-rw-r--r--pkgs/development/web/plone/4.3.nix27
1 files changed, 25 insertions, 2 deletions
diff --git a/pkgs/development/web/plone/4.3.nix b/pkgs/development/web/plone/4.3.nix
index db2092924424..f57b8e63817d 100644
--- a/pkgs/development/web/plone/4.3.nix
+++ b/pkgs/development/web/plone/4.3.nix
@@ -1,7 +1,7 @@
 # DO NOT EDIT THIS FILE!
 #
 # Nix expressions autogenerated with:
 #   bin/pypi2nix -n plone43Packages -d Plone -d mailinglogger -d zc.recipe.egg -d plone.recipe.zope2instance -d plone.recipe.zeoserver -d plone.recipe.varnish -d Pillow -i setuptools -i zc_buildout -i pillow -e plone/4.3.1.json -p plone/4.3.1.txt -o plone/4.3.1.nix
 
 { pkgs, pythonPackages }:
 
@@ -837,6 +837,29 @@ let plone43Packages = pythonPackages.python.modules // rec {
     };
   };
 
+  collective_recipe_template = buildPythonPackage rec {
+    name = "collective.recipe.template-1.9";
+    src = fetchurl {
+      url = "http://pypi.python.org/packages/source/c/collective.recipe.template/collective.recipe.template-1.9.zip";
+      md5 = "f8b8eab3cf183ea92c2e50a54da228e8";
+    };
+    buildInputs = [ pkgs.unzip ];
+    propagatedBuildInputs = [ zc_buildout setuptools pythonPackages.genshi ];
+    doCheck = false;
+    installCommand = ''
+      easy_install --always-unzip --no-deps --prefix="$out" .
+    '';
+    
+    meta = {
+      description = "UNKNOWN";
+      homepage = "UNKNOWN";
+      maintainers = [
+        stdenv.lib.maintainers.garbas
+        stdenv.lib.maintainers.iElectric
+      ];
+    };
+  };
+
   zope_configuration = buildPythonPackage rec {
     name = "zope.configuration-3.7.4";
     src = fetchurl {
@@ -4336,7 +4359,7 @@ let plone43Packages = pythonPackages.python.modules // rec {
   z3c_form = buildPythonPackage rec {
     name = "z3c.form-3.0";
     src = fetchurl {
-      url = "https://pypi.python.org/packages/source/z/z3c.form/z3c.form-3.0.zip";
+      url = "http://pypi.python.org/packages/source/z/z3c.form/z3c.form-3.0.zip";
       md5 = "f9fa3cf56c83722425b3b1be4467ce46";
     };
     buildInputs = [ pkgs.unzip ];
@@ -1,7 +1,7 @@
 #
 # Nix expressions autogenerated with:
-#   bin/pypi2nix -n plone43Packages -d Plone -d mailinglogger -d zc.recipe.egg -d plone.recipe.zope2instance -d plone.recipe.zeoserver -d plone.recipe.varnish -d Pillow -i setuptools -i zc_buildout -i pillow -e plone/4.3.1.json -p plone/4.3.1.txt -o plone/4.3.1.nix
+#   bin/pypi2nix -n plone43Packages -d Plone -d mailinglogger -d zc.recipe.egg -d plone.recipe.zope2instance -d plone.recipe.zeoserver -d plone.recipe.varnish -d collective.recipe.template -d Pillow -i setuptools -i zc_buildout -i pillow -e plone/4.3.1.json -p plone/4.3.1.txt -o plone/4.3.1.nix
 
 { pkgs, pythonPackages }: